"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var Document_1 = __importDefault(require("../nodes/document/Document"));
var XMLParser_1 = __importDefault(require("../xml-parser/XMLParser"));
var Node_1 = __importDefault(require("../nodes/node/Node"));
var DOMException_1 = __importDefault(require("../exception/DOMException"));
/**
 * HTML parser.
 */
var DOMParser = /** @class */ (function () {
    function DOMParser() {
    }
    /**
     * Parses HTML and returns a root element.
     *
     * @param string HTML data.
     * @param mimeType Mime type.
     * @return Root element.
     */
    DOMParser.prototype.parseFromString = function (string, mimeType) {
        if (!mimeType) {
            throw new DOMException_1.default('Second parameter "mimeType" is mandatory.');
        }
        if (mimeType !== 'text/html') {
            throw new DOMException_1.default('The DOMParser in Happy DOM only supports the mime type "text/html".');
        }
        var ownerDocument = this.constructor._ownerDocument;
        var newDocument = new Document_1.default();
        newDocument.defaultView = ownerDocument.defaultView;
        newDocument.childNodes = [];
        newDocument.children = [];
        var root = XMLParser_1.default.parse(newDocument, string, true);
        var documentElement = null;
        var documentTypeNode = null;
        for (var _i = 0, _a = root.childNodes; _i < _a.length; _i++) {
            var node = _a[_i];
            if (node['tagName'] === 'HTML') {
                documentElement = node;
            }
            else if (node.nodeType === Node_1.default.DOCUMENT_TYPE_NODE) {
                documentTypeNode = node;
            }
            if (documentElement && documentTypeNode) {
                break;
            }
        }
        if (documentElement) {
            if (documentTypeNode) {
                newDocument.appendChild(documentTypeNode);
            }
            newDocument.appendChild(documentElement);
            var body = newDocument.querySelector('body');
            if (body) {
                for (var _b = 0, _c = root.childNodes.slice(); _b < _c.length; _b++) {
                    var child = _c[_b];
                    body.appendChild(child);
                }
            }
        }
        else {
            var documentElement_1 = newDocument.createElement('html');
            var bodyElement = newDocument.createElement('body');
            var headElement = newDocument.createElement('head');
            for (var _d = 0, _e = root.childNodes.slice(); _d < _e.length; _d++) {
                var node = _e[_d];
                bodyElement.appendChild(node);
            }
            documentElement_1.appendChild(headElement);
            documentElement_1.appendChild(bodyElement);
            newDocument.appendChild(documentElement_1);
        }
        return newDocument;
    };
    DOMParser._ownerDocument = null;
    return DOMParser;
}());
exports.default = DOMParser;
//# sourceMappingURL=DOMParser.js.map